@@ -1,5 +1,3 @@
-package org.codehaus.plexus.archiver;
-
 /**
  * Copyright 2004 The Apache Software Foundation
  * <p/>
@@ -15,17 +13,15 @@ package org.codehaus.plexus.archiver;
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
+package org.codehaus.plexus.archiver;
 
-public class ArchiverException
-    extends Exception
-{
-    public ArchiverException( String message )
-    {
-        super( message );
+public class ArchiverException extends RuntimeException {
+
+    public ArchiverException(String message) {
+        super(message);
     }
 
-    public ArchiverException( String message, Throwable cause )
-    {
-        super( message, cause );
+    public ArchiverException(String message, Throwable cause) {
+        super(message, cause);
     }
 }
