@@ -6,23 +6,20 @@ import java.io.InputStream;
 
 import org.codehaus.plexus.archiver.bzip2.BZip2UnArchiver;
 
-
 /**
  * Extension of {@link TarFile} for bzip2 compressed files.
  */
-public class BZip2TarFile extends TarFile
-{
+public class BZip2TarFile extends TarFile {
+
     /**
      * Creates a new instance with the given file.
      */
-    public BZip2TarFile( File file )
-    {
-        super( file );
+    public BZip2TarFile(File file) {
+        super(file);
     }
 
-    protected InputStream getInputStream( File file )
-        throws IOException
-    {
-        return BZip2UnArchiver.getBZip2InputStream( super.getInputStream( file ) );
+    @Override
+    protected InputStream getInputStream(File file) throws IOException {
+        return BZip2UnArchiver.getBZip2InputStream(super.getInputStream(file));
     }
 }
